@@ -2,9 +2,7 @@ import os
 from tempfile import TemporaryDirectory
 import pytest
 import numpy
-import matplotlib
 
-matplotlib.use("Qt5Agg")
 import matplotlib.pyplot as plt
 import hyperspy.api as hs
 import atomap.api as am
