@@ -295,7 +295,7 @@ def get_rgb_array(angle, magnitude, rotation=0, angle_lim=None, magnitude_lim=No
 
 def make_color_wheel(ax, rotation=0):
     x, y = np.mgrid[-2.0:2.0:500j, -2.0:2.0:500j]
-    r = (x ** 2 + y ** 2) ** 0.5
+    r = (x**2 + y**2) ** 0.5
     t = np.arctan2(x, y)
     del x, y
     if not (rotation == 0):
@@ -509,7 +509,7 @@ def _make_subplot_map_from_regular_grid(
     plot_title="",
     vector_to_plot=None,
 ):
-    """ Data in the form [(x, y, z)]"""
+    """Data in the form [(x, y, z)]"""
     x_lim = (data[0][0][0], data[0][-1][0])
     y_lim = (data[1][0][0], data[1][0][-1])
     cax = ax.imshow(
@@ -575,7 +575,7 @@ def _make_subplot_map_from_complex_regular_grid(
     plot_title="",
     vector_to_plot=None,
 ):
-    """ amplitude_data and phase_data in the form [(x, y , z)]"""
+    """Amplitude_data and phase_data in the form [(x, y, z)]"""
     x_lim = (amplitude_data[0][0][0], amplitude_data[0][-1][0])
     y_lim = (amplitude_data[1][0][0], amplitude_data[1][0][-1])
     rgb_array = get_rgb_array(
