@@ -1,5 +1,5 @@
 ﻿import numpy as np
-import scipy
+from scipy import ndimage, optimize
 import matplotlib.pyplot as plt
 from matplotlib import cm
 import sklearn.mixture as mixture
@@ -64,7 +64,7 @@ def _detector_threshold(det_image):
 
 
 def _func(x, a, b, c):
-    return a * (x ** -b) + c
+    return a * (x**-b) + c
 
 
 def _radial_profile(data, centre):
@@ -90,7 +90,7 @@ def _radial_profile(data, centre):
 
     y, x = np.indices((data.shape))
     r = np.sqrt((x - centre[0]) ** 2 + (y - centre[1]) ** 2)
-    r = r.astype(np.int)
+    r = r.astype(int)
 
     tbin = np.bincount(r.ravel(), data.ravel())
     nr = np.bincount(r.ravel())
@@ -104,8 +104,8 @@ class InteractiveFluxAnalyser:
             self.profile = profile[0]
             self.radius = radius
             self.flux_profile = flux_profile
-            self.left = np.int(min(self.profile.get_xdata()))
-            self.right = np.int(max(self.profile.get_xdata()))
+            self.left = int(min(self.profile.get_xdata()))
+            self.right = int(max(self.profile.get_xdata()))
             self.l_line = self.profile.axes.axvline(
                 self.left, color="firebrick", linestyle="--"
             )
@@ -134,13 +134,13 @@ class InteractiveFluxAnalyser:
         if event.inaxes != self.profile.axes:
             return
         if event.button == 1:  # Left mouse button
-            left = np.int(event.xdata)
+            left = int(event.xdata)
             if left < self.right:
                 self.left = left
             self.l_line.set_xdata(self.left)
             self.profile.figure.canvas.draw_idle()
         elif event.button == 3:  # Right mouse button
-            right = np.int(event.xdata)
+            right = int(event.xdata)
             if right > self.left:
                 self.right = right
             self.r_line.set_xdata(self.right)
@@ -195,7 +195,7 @@ def find_flux_limits(flux_pattern, conv_angle, limits=None):
     flux_pattern = flux_pattern / np.max(flux_pattern)
 
     # convert 2D image into a 1D profile.
-    centre = scipy.ndimage.measurements.center_of_mass(flux_pattern)
+    centre = ndimage.center_of_mass(flux_pattern)
     flux_profile = _radial_profile(flux_pattern, centre[::-1])
     grad = np.gradient(flux_profile)
     # scale flux_profile relative to the bright field disc.
@@ -263,7 +263,7 @@ def analyse_flux(coords, flux_profile, conv_angle):
     upper = np.sum(radius < coords[1])
     xdata = radius[lower:upper]
     ydata = flux_profile[lower:upper]
-    popt, pcov = scipy.optimize.curve_fit(_func, xdata, ydata, p0=([1, 1, 1]))
+    popt, pcov = optimize.curve_fit(_func, xdata, ydata, p0=([1, 1, 1]))
     fig = plt.figure()
     ax1 = fig.add_subplot(1, 1, 1)
     ax1.plot(xdata, ydata, "b-", label="data")
@@ -324,7 +324,7 @@ def detector_normalisation(
         (det_image.shape[0] / 2, det_image.shape[1] / 2), det_image
     )
     centre_image = np.multiply((m < 512), (1 - threshold_image))
-    centre = scipy.ndimage.measurements.center_of_mass(centre_image)
+    centre = ndimage.center_of_mass(centre_image)
 
     # Using the centre of the detector and sensitivity profile can be made.
     # The maximum gradient of this profile is the inner collection angle
@@ -412,7 +412,8 @@ def get_statistical_quant_criteria(sublattice_list, max_atom_nums):
                 for atom in sublattice.atom_list
             ]
         )
-    int_array = np.asarray(intensities)
+    flat_intensities = [item for sublist in intensities for item in sublist]
+    int_array = np.asarray(flat_intensities)
     int_array = int_array.reshape(-1, 1)
 
     # Fit Gaussian Mixture models with components from 1 to tot_atom_nums
