@@ -102,6 +102,17 @@ class TestRemoveTooCloseAtoms:
         assert len(data_new2)
         assert (data_new2 == data[0]).all()
 
+    def test_intensities(self):
+        data = np.array([[1, 10], [10, 1]])
+        intensities0 = np.array([30, 20])
+        data_new0 = afr._remove_too_close_atoms(data, 20, intensities=intensities0)
+        assert len(data_new0) == 1
+        assert (data_new0 == data[0]).all()
+        intensities1 = np.array([20, 30])
+        data_new1 = afr._remove_too_close_atoms(data, 20, intensities=intensities1)
+        assert len(data_new1) == 1
+        assert (data_new1 == data[1]).all()
+
 
 class TestCropMask:
     def test_radius_1(self):
@@ -406,7 +417,7 @@ class TestMakeMaskCircleCentre:
     def test_radius_2(self):
         arr = np.zeros((3, 3))
         mask = afr._make_mask_circle_centre(arr, 2)
-        np.testing.assert_array_equal(mask, np.zeros((3, 3), dtype=np.bool))
+        np.testing.assert_array_equal(mask, np.zeros((3, 3), dtype=bool))
 
     def test_wrong_arr_dimensions(self):
         arr = np.zeros((3, 3, 4))
@@ -717,7 +728,7 @@ class TestGetFeatureSeparation:
             "int8",
         ]
         s = dd.get_simple_cubic_signal()
-        s *= 10 ** 9
+        s *= 10**9
         for dtype in dtype_list:
             print(dtype)
             s.change_dtype(dtype)
